import unittest
from lofar.calibration.common.datacontainers.calibration_table import CalibrationTable, UnvalidFileException

import logging
from tempfile import NamedTemporaryFile

CALIBRATION_TABLE_FILENAME = 't_calibration_table.in_CalTable-401-HBA-110_190.dat'


class TestCalibrationTable(unittest.TestCase):
    def test_loading(self):
        calibration_table = CalibrationTable.load_from_file(CALIBRATION_TABLE_FILENAME)
        self.assertEqual(calibration_table.observation_station, 'CS401')

    def test_unvalid_file(self):
        with NamedTemporaryFile('w+b') as temp_file:
            temp_file.write(b'stuff')
            temp_file.flush()

            with self.assertRaises(UnvalidFileException):
                _ = CalibrationTable.load_from_file(temp_file.name)

    def test_storing_file(self):
        with NamedTemporaryFile('w+b') as temp_file:
            test_calibration_table = CalibrationTable.load_from_file(CALIBRATION_TABLE_FILENAME)

            test_calibration_table.store_to_file(temp_file.name)

            stored_calibration_table = CalibrationTable.load_from_file(temp_file.name)
            self.assertEqual(test_calibration_table.observation_station,
                             stored_calibration_table.observation_station)


if __name__ == '__main__':
    logging.basicConfig(level=logging.DEBUG)
    unittest.main()
